@@ -19,7 +19,6 @@
 /* Headers we may want to use. */
 #define STDC_HEADERS 1
 #define _GNU_SOURCE 1
-/* #undef HAVE_ALIGNED_ALLOC */
 #define HAVE_ALLOCA_H 1
 #define HAVE_ARPA_INET_H 1
 #define HAVE_ASM_TERMBITS_H 1
@@ -35,6 +34,11 @@
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
 #define HAVE_FPU_CONTROL_H 1
+#define HAVE_GETMNTENT 1
+/* #undef HAVE_GETMNTENT_IN_SYS_MNTAB */
+/* #undef HAVE_GETMNTINFO */
+/* #undef HAVE_GETMNTINFO64 */
+/* #undef HAVE_GETMNTINFO_TAKES_statvfs */
 #define HAVE_GRP_H 1
 /* #undef HAVE_IA64INTRIN_H */
 /* #undef HAVE_IEEEFP_H */
@@ -210,6 +214,7 @@
 #define HAVE_SELECT 1
 #define HAVE_SETENV 1
 #define HAVE_SETLOCALE 1
+#define HAVE_SETMNTENT 1
 #define HAVE_SETUPTERM 1
 #define HAVE_SIGSET 1
 #define HAVE_SIGACTION 1
@@ -217,7 +222,6 @@
 #define HAVE_SIGWAIT 1
 #define HAVE_SIGWAITINFO 1
 #define HAVE_SLEEP 1
-#define HAVE_SNPRINTF 1
 #define HAVE_STPCPY 1
 #define HAVE_STRERROR 1
 #define HAVE_STRCOLL 1
@@ -252,9 +256,6 @@
 #define STRUCT_TIMESPEC_HAS_TV_SEC 1
 #define STRUCT_TIMESPEC_HAS_TV_NSEC 1
 
-#define USE_MB 1
-#define USE_MB_IDENT 1
-
 /* this means that valgrind headers and macros are available */
 /* #undef HAVE_VALGRIND_MEMCHECK_H */
 
@@ -450,8 +451,8 @@
 #define MYSQL_DEFAULT_CHARSET_NAME "utf8mb4"
 #define MYSQL_DEFAULT_COLLATION_NAME "utf8mb4_unicode_ci"
 
-#define USE_MB 1
-#define USE_MB_IDENT 1
+#define USE_MB
+#define USE_MB_IDENT
 
 /* This should mean case insensitive file system */
 /* #undef FN_NO_CASE_SENSE */
@@ -530,16 +531,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 9
-#define MYSQL_VERSION_PATCH 2
+#define MYSQL_VERSION_PATCH 4
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.9.2"
+#define PACKAGE_STRING "MySQL Server 10.9.4"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.9.2"
-#define VERSION "10.9.2"
+#define PACKAGE_VERSION "10.9.4"
+#define VERSION "10.9.4"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
